@@ -29,7 +29,7 @@ known_sources = [
     'coq-ext-lib', 'coq-hammer', 'coq-hott', 'coq-libhyps',
     'coq-menhirlib', 'coq-record-update', 'coq-reduction-effects',
     'coq-stdpp', 'coq-unicoq', 'coq-unimath', 'flocq', 'ott',
-    'paramcoq',
+    'paramcoq', 'coq-serapi',
 
     # level 3
 
@@ -123,14 +123,16 @@ def check_known_tests():
             print(f"- {pkg} doesn't have a corresponding test to run!")
 
 def guess_binary_name(srcname):
-    if srcname.startswith('coq-'):
-        return 'lib' + srcname
     if srcname == 'coq':
         return 'libcoq-stdlib'
+    if srcname == 'coq-serapi':
+        return 'libcoq-serapi-ocaml'
     if srcname == 'elpi':
         return 'libelpi-ocaml'
     if srcname == 'ssreflect':
         return 'libcoq-mathcomp-ssreflect'
+    if srcname.startswith('coq-'):
+        return 'lib' + srcname
     return 'libcoq-' + srcname
 
 def get_source_name(pkgname):
